initZ_interval_truncated: Generate values for latent 'Z' at observed ordinal entires

View source: R/initZ_ordinal.R

initZ_interval_truncatedR Documentation

Generate values for latent Z at observed ordinal entires

Description

Each observed ordinal entry of Z follows truncated normal distribution with mean 0, variance 1 and truncated interval provided in lower and upper. Fill out those entries by their univariate mean if method = "univariate_mean" and by random sampples if method = "sampling"

Usage

initZ_interval_truncated(Lower, Upper, seed = NULL, method = "univariate_mean")

Arguments

Lower

Lower boundary of truncated intervals

Upper

Upper boundary of truncated intervals

seed

random seed used

method

method for initializing the mean

Value

Matrix Z with the same shape as lower


udellgroup/gcimputeR documentation built on Jan. 26, 2023, 10:57 p.m.